#-*- coding:UTF-8 -*-
# ************************************************************************
# NAME
# ---
#   example.py
#
# DATE DE CREATION
# ----------------
#   08/03/2018 - T.Fiolleau - LEGOS / CNRS
#
# AIM
# ---
#   example of the use of the TOOCAN database
#   - load of the MCS TOOCAN database for the WESTERNPACIFIC region in 2014
#	- distribution of the MCS lifetime duration
#	- CDF of the MCS lifetime duration 
#   - CDF of the MCS surface maximum
#	- Vizualisation of the MCS segemntation in 2014/10/15 
#
# INPUTS
# ------
#
# OUTPUTS:
# --------
#
# VERSIONNING HISTORY:
# --------------------  
#  08/03/2018 - T.Fiolleau - LEGOS / CNRS
#	First release
#************************************************************************

### Importation des bibliotheques
import sys
import matplotlib as mpl
import numpy as np 
import netCDF4
from random import randint
from struct import unpack
import matplotlib
import gzip

import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap
from mpl_toolkits.basemap import addcyclic
import matplotlib.gridspec as gridspec
import matplotlib.colors as mc
from matplotlib.patches import Polygon
import glob
from datetime import datetime

from open_imsegTOOCAN_NETCDF import *

class MCS_IntParameters(object): 
  
    def __init__(self):
        self.INT_DCSnumber             = 0
        self.INT_DCS_qualitycontrol           = 0
        self.INT_duration         = 0
        self.INT_classif            = 0
        self.INT_Tmax               = 0.
        self.INT_UTC_timeInit       = 0
        self.INT_localtime_Init     = 0
        self.INT_lonInit           = 0
        self.INT_latInit           = 0
        self.INT_UTC_timeEnd        = 0
        self.INT_localtime_End     = 0
        self.INT_lonEnd           = 0
        self.INT_latEnd           = 0
        self.INT_lonmin           = 0
        self.INT_latmin           = 0      
        self.INT_lonmax           = 0
        self.INT_latmax           = 0
        self.INT_velocityAvg          = 0
        self.INT_distance          = 0
        self.INT_tbmin           = 0
        self.INT_surfmaxPix_235K  = 0
        self.INT_surfmaxkm2_235K  = 0
        self.INT_surfmaxkm2_220K     = 0
        self.INT_surfmaxkm2_210K     = 0
        self.INT_surfmaxkm2_200K     = 0
        self.INT_surfcumkm2_235K     = 0
        self.INT_surfcumkm2_220K     = 0
        self.INT_surfcumkm2_210K     = 0
        self.INT_surfcumkm2_200K     = 0
        self.INT_classif_JIRAK      = 0
        self.INT_classif_MADDOX  = 0
        self.INT_TS_nature_IBTRACS  = 0
        self.INT_TS_mindistance_IBTRACS  = 0
        self.INT_TS_number_IBTRACS  = 0


class MCS_Lifecycle(object):

    def __init__(self):
        self.QCgeo_IRimage            = []
        self.LC_tbmin            = []
        self.LC_tbavg_235K          = []
        self.LC_tbavg_208K          = []
        self.LC_tbavg_200K          = []
        self.LC_tb_90th          = []
        self.LC_surfPix_235K     = []
        self.LC_surfPix_210K     = []
        self.LC_UTC_time            = []
        self.LC_Localtime        = []
        self.LC_lon           = []
        self.LC_lat           = []
        self.LC_x             = []
        self.LC_y             = []
        self.LC_velocity         = []
        self.LC_semiminor_220K      = []
        self.LC_semimajor_220K      = []
        self.LC_orientation_220K = []
        self.LC_ecc_220K   = []
        self.LC_semiminor_235K      = []
        self.LC_semimajor_235K      = []
        self.LC_orientation_235K = []
        self.LC_ecc_235K   = []
        self.LC_surfkm2_235K     = []
        self.LC_surfkm2_220K     = []
        self.LC_surfkm2_210K     = []
        self.LC_surfkm2_200K     = []     

###################################################
def load_TOOCAN(FileTOOCAN):
        lunit=gzip.open(FileTOOCAN,'rt')
        print (FileTOOCAN)
        #
        # Read the Header
        ##########################
        header1 = lunit.readline()
        header2 = lunit.readline()
        header3 = lunit.readline()
        toocan_version = str.lstrip(header3.split(':')[1][0:-1])
        header4 = lunit.readline()
        header5 = lunit.readline()
        header6 = lunit.readline()     
        header7 = lunit.readline()
        Geostationary = str.lstrip(header7.split(':')[1][0:-1])
        header8 = lunit.readline()
        region = str.lstrip(header8.split(':')[1][0:-1])
        header9 = lunit.readline()
        dateStart = str.lstrip(header9.split(':')[1][0:-1])
        header10 = lunit.readline()
        dateEnd = str.lstrip(header10.split(':')[1][0:-1])
        header11 = lunit.readline()
        temporalresolution = str.lstrip(header11.split(':')[1][0:-1])
        header12 = lunit.readline()
        spatialresolution = str.lstrip(header12.split(':')[1][0:-1])
        header13 = lunit.readline()
        Region_longitude = str.lstrip(header13.split(':')[1][0:-1])
        header14 = lunit.readline()
        Region_latitude = str.lstrip(header14.split(':')[1][0:-1])       
        header15 = lunit.readline()
        X_Dimensions = str.lstrip(header15.split(':')[1][0:-1])
        header16 = lunit.readline()
        Y_Dimensions = str.lstrip(header16.split(':')[1][0:-1])
        header17 = lunit.readline()
        DCS_occurences = str.lstrip(header17.split(':')[1][0:-1])
        header18 = lunit.readline()
        header19 = lunit.readline()
        header20 = lunit.readline()
        header21 = lunit.readline()
        header22 = lunit.readline()
        header23 = lunit.readline()
        data = []
        iMCS = -1

        lines = lunit.readlines()
        for iline in lines:
             Values = iline.split()
             #print (iline,Values)

             if(Values[0] == '==>'):
                 #
                 # Read the integrated parameters of the convective systems
                 ###########################################################
                 data.append(MCS_IntParameters())
                 iMCS = iMCS+1
                 data[iMCS].INT_DCSnumber       = int(Values[1])      # Label of the convective system in the segmented images
                 data[iMCS].INT_DCS_qualitycontrol        = int(Values[2])      # Quality control of the convective system 
                 data[iMCS].INT_classif       = int(Values[3])   
                 data[iMCS].INT_duration      = float(Values[4])       #duration of the convective system (number of slot)
                 data[iMCS].INT_UTC_timeInit    = int(Values[5])      # time TU of initiation of the convective system
                 data[iMCS].INT_localtime_Init   = int(Values[6])      # local time of inititiation
                 data[iMCS].INT_lonInit       = float(Values[7])      # longitude of the center of mass at inititiation
                 data[iMCS].INT_latInit       = float(Values[8])      # latitude of the center of mass at inititiation
                 data[iMCS].INT_UTC_timeEnd     = int(Values[9])      # time TU of dissipation of the convective system
                 data[iMCS].INT_localtime_End = int(Values[10])     # local hour of dissipation
                 data[iMCS].INT_lonEnd        = float(Values[11])     # longitude of the center of mass at dissipation
                 data[iMCS].INT_latEnd        = float(Values[12])     # latitude of the center of mass at dissipation
                 data[iMCS].INT_velocityAvg          = float(Values[13])     # average velocity during its life cycle(m/s)
                 data[iMCS].INT_distance          = float(Values[14])     # distance covered by the convective system during its life cycle(km)
                 data[iMCS].INT_lonmin        = float(Values[15])     # longitude min of the center of mass during its life cycle
                 data[iMCS].INT_latmin          = float(Values[16])     # latitude min of the center of mass during its life cycle
                 data[iMCS].INT_lonmax        = float(Values[17])     # longitude max of the center of mass during its life cycle
                 data[iMCS].INT_latmax        = float(Values[18])     # latitude max of the center of mass during its life cycle
                 data[iMCS].INT_tbmin         = float(Values[19])     #minimum Brigthness temperature (K)
                 data[iMCS].INT_surfmaxPix_235K  = int(Values[20])    # maximum surface for a 235K threshold of the convective system during its life cycle (pixel)
                 data[iMCS].INT_surfmaxkm2_235K  = float(Values[21])     #maximum surfacefor a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_surfmaxkm2_220K  = float(Values[22])     #maximum surfacefor a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_surfmaxkm2_210K  = float(Values[23])     #maximum surfacefor a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_surfmaxkm2_200K  = float(Values[24])     #maximum surfacefor a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_surfcumkm2_235K     = float(Values[25])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_classif_JIRAK    = float(Values[26])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_classif_MADDOX      = float(Values[27])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_TS_number_IBTRACS      = float(Values[28])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_TS_nature_IBTRACS      = float(Values[29])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)
                 data[iMCS].INT_TS_mindistance_IBTRACS    = float(Values[30])  # integrated cumulated surface for a 235K threshold of the convective system during its life cycle (km2)

                 data[iMCS].clusters = MCS_Lifecycle()

                 inc = 0
             else:
                 #
                 # Read the parameters of the convective systems 
                 #along their life cycles
                 ##################################################
                 data[iMCS].clusters.QCgeo_IRimage.append(int(Values[0]))                  #quality control on the Infrared image
                 data[iMCS].clusters.LC_tbmin.append(float(Values[1]))                 #min brightness temperature of the convective system at day TU (K)
                 data[iMCS].clusters.LC_tbavg_235K.append(float(Values[2]))                    #average brightness temperature of the convective system at day TU (K) 
                 data[iMCS].clusters.LC_tbavg_208K.append(float(Values[3]))                    #average brightness temperature of the convective system at day TU (K) 
                 data[iMCS].clusters.LC_tbavg_200K.append(float(Values[4]))                    #average brightness temperature of the convective system at day TU (K) 
                 data[iMCS].clusters.LC_tb_90th.append(float(Values[5]))                   #average brightness temperature of the convective system at day TU (K) 
                 data[iMCS].clusters.LC_UTC_time.append(int(Values[6]))                 #day TU 
                 data[iMCS].clusters.LC_Localtime.append(int(Values[7]))             #local hour (h)
                 data[iMCS].clusters.LC_lon.append(float(Values[8]))                   #longitude of the center of mass 
                 data[iMCS].clusters.LC_lat.append(float(Values[9]))                   #latitude of the center of mass 
                 data[iMCS].clusters.LC_x.append(int(Values[10]))                      #column of the center of mass (pixel)
                 data[iMCS].clusters.LC_y.append(int(Values[11]))                      #line of the center of mass(pixel)
                 data[iMCS].clusters.LC_velocity.append(float(Values[12]))             #instantaneous velocity of the center of mass (m/s)
                 data[iMCS].clusters.LC_semiminor_235K.append(float(Values[13]))       #
                 data[iMCS].clusters.LC_semimajor_235K.append(float(Values[14]))       #
                 data[iMCS].clusters.LC_ecc_235K.append(float(Values[15]))    #
                 data[iMCS].clusters.LC_orientation_235K.append(float(Values[16]))     #
                 data[iMCS].clusters.LC_semiminor_220K.append(float(Values[17]))       #
                 data[iMCS].clusters.LC_semimajor_220K.append(float(Values[18]))       #
                 data[iMCS].clusters.LC_ecc_220K.append(float(Values[19]))    #
                 data[iMCS].clusters.LC_orientation_220K.append(float(Values[20]))     #
                 data[iMCS].clusters.LC_surfPix_235K.append(int(Values[21]))               #surface of the convective system at time day TU (pixel)
                 data[iMCS].clusters.LC_surfPix_210K.append(int(Values[22]))               #surface of the convective system at time day TU (pixel)                 
                 data[iMCS].clusters.LC_surfkm2_235K.append(float(Values[23]))         #surface of the convective system for a 235K threshold
                 data[iMCS].clusters.LC_surfkm2_220K.append(float(Values[24]))         #surface of the convective system for a 200K threshold
                 data[iMCS].clusters.LC_surfkm2_210K.append(float(Values[25]))         #surface of the convective system for a 210K threshold
                 data[iMCS].clusters.LC_surfkm2_200K.append(float(Values[26]))         #surface of the convective system for a 220K threshold

        lunit.close()
   
        return (data)    




##################################################
##################################################
##################################################
# DEFINE the Path of the TOOCAN runs 
##################################################
##################################################
##################################################
path 			  = '../../'


#
# Selection of the period / region of interest
# iregion = Region of interest
# 0 ==> AFRICA
# 1 ==> INDIA
# 2 ==> WESTERNPACIFIC
# 3 ==> EASTERNPACIFIC
# 4 ==> AMERICA
###############################################
iregion = 4
year 	= 2016
month 	= 5
day		= 15



if(iregion == 0):
		REGION      = 'AFRICA'
		SAT         = 'MSG3'
		lonmin      = -40
		lonmax      = 40
		latmin      = -30
		latmax      = 30
if(iregion == 1):
		REGION      = 'INDIA'
		SAT         = 'MET7'
		lonmin      = 40
		lonmax      = 101
		latmin      = -30
		latmax      = 30
#
# if Region == WESTERNPACIFIC and the date is before 20150601
# then the satellite used is MTSAT-2
# For technical reasons inherent to the Geostationary satellite, the SouthScan is not processed
###############################################################################################
if( (iregion == 2) & (year*100+month < 201506)) :
		REGION      = 'WESTERNPACIFIC'
		SAT         = 'MTSAT2'
		lonmin      = 101
		lonmax      = 185
		latmin      = 0
		latmax      = 30
#
# if Region == WESTERNPACIFIC and the date is after 20150601
# then the satellite used is HIMAWARI-8
###############################################################
if( (iregion == 2) & (year*100+month >= 201506)) :
		REGION      = 'WESTERNPACIFIC'
		SAT         = 'HIMAWARI8'
		lonmin      = 101
		lonmax      = 185
		latmin      = -30
		latmax      = 30		
if(iregion == 3):
		REGION      = 'EASTERNPACIFIC'
		SAT         = 'GOES15'
		lonmin      = 185
		lonmax      = 250
		latmin      = -30
		latmax      = 30
if(iregion == 4):
		REGION      = 'AMERICA'
		SAT         = 'GOES13'
		lonmin      = -106
		lonmax      = -40
		latmin      = -30
		latmax      = 30



##############################################################################
# Path of the TOOCAN segmented images
##############################################################################
pathImage_TOOCAN  = path+REGION+'/'+str(year)+'/'




##########################################################
# Load the MCS parameters into a class object
##########################################################
#All_FileTOOCAN = sorted(glob.glob(path+REGION+'/'+str(year)+'/FileTracking_ASCII/*.dat.gz'))
#for ifileTOOCAN in np.arange(0,len(All_FileTOOCAN),1):
#	FileTOOCAN = All_FileTOOCAN[ifileTOOCAN]
#	print (FileTOOCAN)
#	if(ifileTOOCAN == 0) : 
#		data    = load_TOOCAN(FileTOOCAN)
#
#	else:
#		data     = data + load_TOOCAN(FileTOOCAN)

# selection of the MCS correctly identified and tracked 
#for example : qc_MCS =  11108
#First digit =1        MCS initiation OK 
#Second digit = 1     MCS dissipation OK 
#Third digit = 1          MCS not impacted by the image boundaries
#Two last digit = 08     less than 8 interpolated GEO images occuring during the MCS tracking
#################################################################################################################################################
data = [data[iMCS] for iMCS in np.arange(0,len(data),1) if(int(data[iMCS].INT_DCS_qualitycontrol) <= 11108)]



##########################################################################
# Selection of the MCSs which occured within the region of interest
##########################################################################
data_MCSselection = []
for iMCS in np.arange(0,len(data),1):
		id = [ilife for ilife in np.arange(0,data[iMCS].INT_duration*2,1,dtype=int) if( (data[iMCS].clusters.LC_lon[ilife] >= lonmin)  &  (data[iMCS].clusters.LC_lon[ilife] <= lonmax) &  (data[iMCS].clusters.LC_lat[ilife] >= latmin)  &  (data[iMCS].clusters.LC_lat[ilife] <= latmax)) ]
		if(np.size(id) > 0):
			data_MCSselection.append(data[iMCS])
print (len(data),len(data_MCSselection))

#
# Get the lifetime duration, Smax, Scum variables of all the segmented MCS previously selected 
##########################################################################################################
LifetimeDuration = [data_MCSselection[iMCS].INT_duration for iMCS in np.arange(0,len(data_MCSselection),1)]
Smax             = [data_MCSselection[iMCS].INT_surfmaxkm2_235K for iMCS in np.arange(0,len(data_MCSselection),1)]
Scum             = [data_MCSselection[iMCS].INT_surfcumkm2_235K for iMCS in np.arange(0,len(data_MCSselection),1)]


#
# Plot the distribution /CDF of the MCS integrated paramaters : LifetimeDuration/Smax 
##########################################################################################
BINS = 2*np.arange(141)

fig = plt.figure(figsize=(25, 20))
ax1 = fig.add_axes([0.25, 0.25, 0.75, 0.75])
n, bins, patches = ax1.hist(LifetimeDuration, BINS, histtype='step', lw=2, color='mediumblue', label='lifetime duration [h]',log=1,rwidth = 15,linewidth=7.0)
plt.xticks(range(0,81,4))

plt.xlabel('Lifetime duration [h]' ,fontsize=30)
plt.ylabel('Population', fontsize=30)
plt.xlim(0, 80)
plt.ylim(0, 1500000)
plt.grid(True,linewidth=2)


file="histo_lifetime.png"
plt.savefig(file, dpi=150, bbox_inches='tight')
fig.clf()
plt.close()


fig = plt.figure(figsize=(25, 20))
ax1 = fig.add_axes([0.25, 0.25, 0.75, 0.75])
n, bins, patches = ax1.hist(LifetimeDuration, BINS, histtype='step', lw=2,  rwidth = 15,cumulative =1,color='mediumblue',linewidth=7.0, label='MCS population')
n, bins, patches = ax1.hist(LifetimeDuration, BINS,weights =Scum, histtype='step', lw=2, color='orange',rwidth = 15,cumulative =1,linewidth=7.0, label='MCS population weighted by their cumulated surface')

plt.xlabel('Lifetime duration [h]' ,fontsize=30)
plt.ylabel('Population', fontsize=30)
plt.xticks(range(0,81,4))
plt.legend(loc='lower right')

plt.xlim(0, 80)
plt.ylim(0, 1)
plt.grid(True,linewidth=2)


file="cdf_lifetime.png"
plt.savefig(file, dpi=150, bbox_inches='tight')
fig.clf()
plt.close()


BINS = 100*np.arange(1750000)
fig = plt.figure(figsize=(25, 20))
ax1 = fig.add_axes([0.25, 0.25, 0.75, 0.75])
n, bins, patches = ax1.hist(Smax, BINS, histtype='step', lw=2,color='mediumblue',rwidth = 15,cumulative =1,linewidth=7.0)
plt.xlabel('Smax [km2]' ,fontsize=30)
plt.ylabel('Population', fontsize=30)
ax1.set_xscale('log')
plt.xlim(100, 1000000)

plt.ylim(0, 1)
plt.grid(True,linewidth=2)


file="cdf_Smax.png"
plt.savefig(file, dpi=150, bbox_inches='tight')
fig.clf()
plt.close()



#
# Random for the colors between 0 and 255
##################################################	
tabrandom = np.random.randint(255, size=30000000)
tabrandom[0] = -999


########################################################
#computation of the number of the day since 01/01/1970
########################################################
offset  = datetime(1970,1,1,0)
dateTest = datetime(int(year), int(month),int(day), 0)
dateTest_since1970	= dateTest-offset
jday_since1970 = dateTest_since1970.days*60*24*60+dateTest_since1970.seconds
jBegin_since1970 = dateTest_since1970.days*60*24*60+dateTest_since1970.seconds
jEnd_since1970 = (dateTest_since1970.days+1)*60*24*60+dateTest_since1970.seconds

#########################################################
# Selection of the MCS which occured at the given date 
#########################################################
idMCS = [iMCS for iMCS in np.arange(0,len(data),1) if(int(data[iMCS].INT_UTC_timeInit) < jEnd_since1970 and int(data[iMCS].INT_UTC_timeEnd) >= jBegin_since1970)]

#########################################################
# Loop on the 48 slots of the given date 
#########################################################
for slot in np.arange(1,49,1):
	hour   = (slot-1) / 2
	minute =0
	if((slot-1) % 2 == 1):
		minute = 30
	print (hour,minute)
	filesegImages   = path+REGION+'/'+str(year)+'/'+str(year)+'_'+str(month).zfill(2)+'_'+str(day).zfill(2)+'/ToocanCloudMask_'+str(year)+str(month).zfill(2)+str(day).zfill(2)+'-'+str(slot).zfill(2)+'.nc'

	####################################################
	# Open a segmented image produced by TOOCAN
	####################################################
	(imtoocan,matlon_TOOCAN,matlat_TOOCAN) = open_imsegTOOCAN_NETCDF(filesegImages)
	imtoocan = imtoocan.astype(int)
	imtoocan = imtoocan.data

	ind  =  np.where((matlon_TOOCAN >= lonmin) & (matlon_TOOCAN <= lonmax) & (matlat_TOOCAN >= latmin) & (matlat_TOOCAN <= latmax))

	colmin_TOOCAN =  np.min(ind[0])
	colmax_TOOCAN =  np.max(ind[0])
	linemin_TOOCAN =  np.min(ind[1])
	linemax_TOOCAN =  np.max(ind[1])

	imtoocan     	  = imtoocan[colmin_TOOCAN:colmax_TOOCAN+1,linemin_TOOCAN:linemax_TOOCAN+1]
	matlat_TOOCAN     = matlat_TOOCAN[colmin_TOOCAN:colmax_TOOCAN+1,linemin_TOOCAN:linemax_TOOCAN+1]
	matlon_TOOCAN     = matlon_TOOCAN[colmin_TOOCAN:colmax_TOOCAN+1,linemin_TOOCAN:linemax_TOOCAN+1]

	ind = np.where(imtoocan > 0)
	imtoocan2 = np.zeros((np.shape(imtoocan)))
	imtoocan2[ind[0][:],ind[1][:]]= tabrandom[imtoocan[ind[0][:],ind[1][:]]]
	Hmasked = np.ma.masked_where(imtoocan2 <= 0,imtoocan2) # Mask pixels with a value of zero

	#######################################################################
	# Selection of the MCS which occured at the given date and at the slot
	#######################################################################
	#idMCS_slot = [iMCS for iMCS in np.arange(0,len(idMCS),1) if(data[idMCS[iMCS]].clusters.LC_UTC_time[ilife] == jBegin_since1970+(hour*60*60+minute*60) )]

	###################
	# figure 
	###################
	fig = plt.figure(figsize=(20, 5))
	layout = (1,1)

	plot_1 = plt.subplot2grid(layout, (0, 0))

	map = Basemap(projection='merc',lat_0 = 0, lon_0 = (lonmax+lonmin)/2, area_thresh = 0.1,llcrnrlon=lonmin, llcrnrlat=latmin,urcrnrlon=lonmax, urcrnrlat=latmax,ax=plot_1)
	map.shadedrelief()
	
	parallels = np.arange(-40.,40.,10.)
	map.drawparallels(parallels,labels=[True,True,True,True], color='grey')
	meridians = np.arange(-360.,360.,20.)
	map.drawmeridians(meridians,labels=[True,True,True,True], color='grey')

	x, y = map(matlon_TOOCAN, matlat_TOOCAN)
	r=map.pcolormesh(x, y, Hmasked,shading='flat', cmap = plt.cm.jet,vmin =0,vmax =255)
	plot_1.contour(x, y, imtoocan2,levels =np.arange(255),colors='white',linewidths=0.2)
	plot_1.contour(x, y, imtoocan2,levels =np.arange(255),colors='grey',linewidths=0.18)

	#########################################################
	# Loop on the number of MCS to plot the MCS trajectories
	#########################################################
	for iMCS in np.arange(0,len(idMCS),1):
		
		#######################################################################
		# Selection of the MCS which occured at the given date and at the slot
		#######################################################################
		idslot = [ilife for ilife in np.arange(0,data[idMCS[iMCS]].INT_duration*2,1,dtype=int) if( ( data[idMCS[iMCS]].clusters.LC_UTC_time[ilife] == jBegin_since1970+(hour*60*60+minute*60)))  ]
		
		if(np.size(idslot) > 0):
			lons = data[idMCS[iMCS]].clusters.LC_lon[0:idslot[0]+1]
			lats = data[idMCS[iMCS]].clusters.LC_lat[0:idslot[0]+1]
			xtraj, ytraj = map(lons, lats)
			map.plot(xtraj, ytraj, marker='None',color='black')
			xtraj, ytraj = map(lons[idslot[0]], lats[idslot[0]])
			map.plot(xtraj, ytraj, marker='o',color='black',markersize=2)
				


			if(np.size(idslot) > 1):
				import sys
				sys.exit("Error message") 
			if(idslot[0] > 0):
				lons = data[idMCS[iMCS]].clusters.LC_lon[idslot[0]-1:idslot[0]+1]
				lats = data[idMCS[iMCS]].clusters.LC_lat[idslot[0]-1:idslot[0]+1]
				xtraj, ytraj = map(lons, lats)
			
	file="TOOCAN_"+REGION+'_'+str(year).zfill(4)+str(month).zfill(2)+str(day).zfill(2)+"_"+str(slot).zfill(2)+".png"
	plt.savefig(file, dpi=150, bbox_inches='tight')
	fig.clf()
	plt.close()
	#import sys
	#sys.exit("Error message")
